@@ -10,14 +10,6 @@ from .data_input import dict_to_wide, check_valid_batch_dict
 
 from ..multivariate.methods import MCUVScaler, PCA
 
-logger = logging.getLogger(__name__)
-logger.setLevel(logging.DEBUG)
-fh = logging.FileHandler(f"{__file__}.log")
-fh.setLevel(logging.DEBUG)
-formatter = logging.Formatter("%(asctime)s - %(name)s - %(levelname)s - %(message)s")
-fh.setFormatter(formatter)
-logger.addHandler(fh)
-
 epsqrt = np.sqrt(np.finfo(float).eps)
 
 
@@ -58,9 +50,7 @@ def determine_scaling(
     collector_mins = []
     for _, batch in batches.items():
         if settings["robust"]:
-            rnge = batch[columns_to_align].quantile(0.98) - batch[
-                columns_to_align
-            ].quantile(0.02)
+            rnge = batch[columns_to_align].quantile(0.98) - batch[columns_to_align].quantile(0.02)
         else:
             rnge = batch[columns_to_align].max() - batch[columns_to_align].min()
 
@@ -136,9 +126,7 @@ def reverse_scaling(
     for batch_id, batch in batches.items():
         out[batch_id] = batch[columns_to_align].copy()
         for tag, column in out[batch_id].iteritems():
-            out[batch_id][tag] = (
-                column * scale_df.loc[tag, "Range"] + scale_df.loc[tag, "Minimum"]
-            )
+            out[batch_id][tag] = column * scale_df.loc[tag, "Range"] + scale_df.loc[tag, "Minimum"]
     return out
 
 
@@ -260,7 +248,6 @@ def one_iteration_dtw(
             )
             if settings["show_progress"]:
                 message = f"  * {batch_id}: distance = {result.distance}"
-                logger.debug(message)
                 print(message)
         except ValueError:
             assert False, f"Failed on batch {batch_id}"
@@ -324,9 +311,7 @@ def batch_dtw(
         default_settings.update(settings)
     settings = default_settings
     assert settings["maximum_iterations"] >= 3, "At least 3 iterations are required"
-    assert (
-        reference_batch in batches
-    ), "`reference_batch` was not found in the dict of batches."
+    assert reference_batch in batches, "`reference_batch` was not found in the dict of batches."
     settings["subsample"] = int(settings["subsample"])
 
     assert check_valid_batch_dict(batches, no_nan=True)
@@ -347,7 +332,6 @@ def batch_dtw(
     ):
         if settings["show_progress"]:
             message = f"Iter = {iter} and norm = {np.linalg.norm(delta_weight)}"
-            logger.debug(message)
             print(message)
 
         iter += 1
@@ -367,9 +351,7 @@ def batch_dtw(
         # Deviations from the average batch:
         next_weights = np.zeros((1, refbatch_sc.shape[1]))
         for batch_id, result in aligned_batches.items():
-            next_weights += np.nansum(
-                np.power(result.synced - average_batch, 2), axis=0
-            )
+            next_weights += np.nansum(np.power(result.synced - average_batch, 2), axis=0)
             # TODO: use quadratic weights for now, but try sum of the absolute values instead
             #  np.abs(result.synced - average_batch).sum(axis=0)
 
@@ -382,9 +364,7 @@ def batch_dtw(
             # problematic_threshold = dist_df["Distance"].quantile(0.95)
 
         next_weights = 1.0 / np.where(next_weights > epsqrt, next_weights, 10000)
-        weight_vector = (
-            next_weights / np.sum(next_weights) * len(columns_to_align)
-        ).ravel()
+        weight_vector = (next_weights / np.sum(next_weights) * len(columns_to_align)).ravel()
         # If change in delta_weight is small, we terminate early; no need to fine-tune excessively.
         delta_weight = np.diag(weight_matrix) - weight_vector  # old - new
 
@@ -413,10 +393,7 @@ def batch_dtw(
         "-".join(item)
         for item in zip(
             aligned_wide_df.columns.get_level_values(0),
-            [
-                str(val).zfill(max_places)
-                for val in aligned_wide_df.columns.get_level_values(1)
-            ],
+            [str(val).zfill(max_places) for val in aligned_wide_df.columns.get_level_values(1)],
         )
     ]
     aligned_wide_df.columns = new_labels
@@ -509,18 +486,14 @@ def find_average_length(batches: Dict[str, pd.DataFrame], settings: dict = None)
         default_settings.update(settings)
     settings = default_settings
 
-    batch_lengths = pd.Series(
-        {batch_id: df.shape[0] for batch_id, df in batches.items()}
-    )
+    batch_lengths = pd.Series({batch_id: df.shape[0] for batch_id, df in batches.items()})
     if settings["robust"]:
         # If multiple batches of the median length, return the last one.
         return batch_lengths.index[
             np.where((batch_lengths == batch_lengths.median()).values)[0][-1]
         ]
     else:
-        return batch_lengths.index[
-            (batch_lengths - batch_lengths.mean()).abs().argmin()
-        ]
+        return batch_lengths.index[(batch_lengths - batch_lengths.mean()).abs().argmin()]
 
 
 def find_reference_batch(
